<?php
/*Filters and Actions*/
if ( ! function_exists( 'love_pet_action_theme_setup' ) ) :
	function love_pet_action_theme_setup() {

		/*Make Theme available for translation*/
		load_theme_textdomain( 'love-pet', get_template_directory() . '/languages' );

		// Add RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );
		// Enable support for Post Thumbnails, and declare two sizes.
		add_theme_support( 'post-thumbnails' );
		add_theme_support('title-tag');

		/*Switch default core markup for search form, comment form, and comments to output valid HTML5.*/
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) );

		/*Enable support for Post Formats. See http://codex.wordpress.org/Post_Formats*/
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'audio',
			'quote',
			'link',
			'gallery',
		) );

		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );
	}
endif;
add_action( 'after_setup_theme', 'love_pet_action_theme_setup' );

/**
 * Extend the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Presence of header image.
 * 3. Index views.
 * 4. Full-width content layout.
 * 5. Presence of footer widgets.
 * 6. Single views.
 * 7. Featured content layout.
 *
 * @param array $classes A list of existing body class values.
 *
 * @return array The filtered body class list.
 * @internal
 */
function love_pet_filter_theme_body_classes( $classes ) {
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	if ( get_header_image() ) {
		$classes[] = 'header-image';
	} else {
		$classes[] = 'masthead-fixed';
	}

	if ( is_archive() || is_search() || is_home() ) {
		$classes[] = 'list-view';
	}

	if ( function_exists('fw_ext_sidebars_get_current_position') ) {
		$current_position = fw_ext_sidebars_get_current_position();
		if ( in_array( $current_position, array( 'full', 'left' ) )
		     || empty($current_position)
		     || is_page_template( 'page-templates/full-width.php' )
		     || is_page_template( 'page-templates/contributors.php' )
		     || is_attachment()
		) {
			$classes[] = 'full-width';
		}
	} else {
		$classes[] = 'full-width';
	}

	if ( is_active_sidebar( 'blog-widget' ) ) {
		$classes[] = 'footer-widgets';
	}

	if ( is_singular() && ! is_front_page() ) {
		$classes[] = 'singular';
	}

	return $classes;
}

add_filter( 'body_class', 'love_pet_filter_theme_body_classes' );

/**
 * Extend the default WordPress post classes.
 *
 * Adds a post class to denote:
 * Non-password protected page with a post thumbnail.
 *
 * @param array $classes A list of existing post class values.
 *
 * @return array The filtered post class list.
 * @internal
 */
function love_pet_filter_theme_post_classes( $classes ) {
	if ( ! post_password_required() && ! is_attachment() && has_post_thumbnail() ) {
		$classes[] = 'has-post-thumbnail';
	}

	return $classes;
}

add_filter( 'post_class', 'love_pet_filter_theme_post_classes' );

/**
 * Create a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 *
 * @return string The filtered title.
 * @internal
 */
function love_pet_filter_theme_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() ) {
		return $title;
	}

	// Add the site name.
	$title .= get_bloginfo( 'name', 'display' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 ) {
		$title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'love-pet'), max( $paged, $page ) );
	}

	return $title;
}

add_filter( 'wp_title', 'love_pet_filter_theme_wp_title', 10, 2 );

/*Flush out the transients used in fw_theme_categorized_blog*/
function love_pet_action_theme_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'fw_theme_category_count' );
}
add_action( 'edit_category', 'love_pet_action_theme_category_transient_flusher' );
add_action( 'save_post', 'love_pet_action_theme_category_transient_flusher' );

/*Register widget areas*/
function love_pet_action_theme_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Widget Area', 'love-pet'),
		'id'            => 'blog-widget',
		'description'   => esc_html__( 'Appears in the blog sidebar section of the site.', 'love-pet'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area', 'love-pet'),
		'id'            => 'footer-widget',
		'description'   => esc_html__( 'Appears in the footer section of the site.', 'love-pet'),
		'before_widget' => '<div class="col-md-3 col-lg-3"><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside></div>',
		'before_title'  => '<h6 class="footer-widget-title">',
		'after_title'   => '</h6>',
	) );

	if(class_exists('Woocommerce')) {
		register_sidebar(array(
			'name' => esc_html__('Shop Widget Area', 'love-pet'),
			'id' => 'shop-widget',
			'description' => esc_html__('Appears in the sidebar of shop page.', 'love-pet'),
			'before_widget' => '<aside id="%1$s" class="widget shop %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h6 class="shop-widget-title">',
			'after_title' => '</h6>',
		));
	}
}
add_action( 'widgets_init', 'love_pet_action_theme_widgets_init' );

/** Filter to wp_editor to optimize fw_resize function*/
add_filter( 'jpeg_quality', 'love_pet_filter_theme_image_full_quality' );
add_filter( 'wp_editor_set_quality', 'love_pet_filter_theme_image_full_quality' );
function love_pet_filter_theme_image_full_quality( $quality ) {
	return 100;
}

/*Custom css for admin*/
function love_pet_load_custom_wp_admin_style() {
    wp_register_style( 'love_pet_custom_admin_css', get_template_directory_uri() . '/css/admin.css', false, '1.0.0' );
    wp_enqueue_style( 'love_pet_custom_admin_css' );
}
add_action( 'admin_enqueue_scripts', 'love_pet_load_custom_wp_admin_style' );

/*Install Demo content*/
function love_pet_backups_demos($demos) {
	$demos_array = array(
		'lovepet' => array(
			'title' => esc_html__('Love Pet Demo', 'love-pet'),
			'screenshot' => get_template_directory_uri().'/screenshot.png',
			'preview_link' => '//haintheme.com/demo/wp/love-pet/',
		),
	);

	$download_url = 'http://haintheme.com/ht-demos/';

	foreach ($demos_array as $id => $data) {
		$demo = new FW_Ext_Backups_Demo($id, 'piecemeal', array(
			'url' => $download_url,
			'file_id' => $id,
		));
		$demo->set_title($data['title']);
		$demo->set_screenshot($data['screenshot']);
		$demo->set_preview_link($data['preview_link']);

		$demos[ $demo->get_id() ] = $demo;

		unset($demo);
	}

	return $demos;
}
add_filter('fw:ext:backups-demo:demos', 'love_pet_backups_demos');


/**
 * Fixed problem Unyson & YITH
 * conflict color picker
 * @return [type] [description]
 */
function lovepet_deregister_woocommerce_setting(){
	$screen = get_current_screen();
	if ( $screen->post_type == 'page' ){
			wp_deregister_script( 'woocommerce_settings' );
	}
}
add_action( 'admin_enqueue_scripts', 'lovepet_deregister_woocommerce_setting', 99 );